@@ -36,7 +36,6 @@
 
 #include "command_p.h"
 
-#include <utils/kdlogtextwidget.h>
 #include <utils/gnupg-helper.h>
 
 #include <KProcess>
@@ -53,6 +52,7 @@
 #include <QVBoxLayout>
 #include <KSharedConfig>
 #include <QFontDatabase>
+#include <QTextEdit>
 
 static const int PROCESS_TERMINATE_TIMEOUT = 5000; // milliseconds
 
@@ -78,7 +78,8 @@ Q_SIGNALS:
 public Q_SLOTS:
     void append(const QString &line)
     {
-        ui.logTextWidget.message(line);
+        ui.logTextWidget.append(line);
+        ui.logTextWidget.ensureCursorVisible();
     }
     void clear()
     {
@@ -103,7 +104,7 @@ private:
     }
 
     struct Ui {
-        KDLogTextWidget logTextWidget;
+        QTextEdit   logTextWidget;
         QPushButton     updateButton, closeButton;
         QVBoxLayout vlay;
         QHBoxLayout  hlay;
@@ -123,8 +124,7 @@ private:
             KDAB_SET_OBJECT_NAME(hlay);
 
             logTextWidget.setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
-            logTextWidget.setMinimumVisibleLines(25);
-            logTextWidget.setMinimumVisibleColumns(80);
+            logTextWidget.setReadOnly(true);
 
             vlay.addWidget(&logTextWidget, 1);
             vlay.addLayout(&hlay);
