@@ -48,7 +48,7 @@ CryptoOperationsConfigurationPage::CryptoOperationsConfigurationPage(QWidget *pa
     lay->setMargin(0);
     mWidget = new CryptoOperationsConfigWidget(this);
     lay->addWidget(mWidget);
-    connect(mWidget, SIGNAL(changed()), this, SLOT(changed()));
+    connect(mWidget, &CryptoOperationsConfigWidget::changed, this, QOverload<>::of(&Kleo::Config::CryptoOperationsConfigurationPage::changed));
 
     load();
 }
